﻿/**
* DevExpress Analytics (accessibility\_dxMutationObserver.js)
* Version:  24.2.7
* Build date: Apr 29, 2025
* Copyright (c) 2012 - 2025 Developer Express Inc. ALL RIGHTS RESERVED
* License: https://www.devexpress.com/Support/EULAs/universal.xml
*/
export function initializeMutationObserver(element, mutationObserverArgs, accessibilityCompliant) {
    const { onInitialized, onDomUpdated, onCleanUp, controlElementClassName } = mutationObserverArgs;
    const observerCallback = (records, selector) => {
        records.some(record => record.target.querySelector(`.${selector}`)) && onDomUpdated();
    };
    const observer = new MutationObserver(records => observerCallback(records, controlElementClassName));
    observer.observe(element, {
        childList: true,
        subtree: true,
        attributes: true,
        attributeFilter: ['style']
    });
    onInitialized(element, accessibilityCompliant);
    return () => {
        observer.disconnect();
        onCleanUp();
    };
}
