﻿/**
* DevExpress Analytics (query-builder\dataSource\federation\federationSource.js)
* Version:  24.2.7
* Build date: Apr 29, 2025
* Copyright (c) 2012 - 2025 Developer Express Inc. ALL RIGHTS RESERVED
* License: https://www.devexpress.com/Support/EULAs/universal.xml
*/
import { ModelSerializer } from '../../../serializer/serializer';
import { Disposable } from '../../../serializer/disposable';
import { extend } from '../../../serializer/_utils';
import { sourceSerializationInfo } from './federationDataSourceMeta';
export class FederationSource extends Disposable {
    constructor(model, serializer, pathParts, sourceName) {
        super();
        serializer = serializer || new ModelSerializer();
        const [dataSource, ...dataMember] = pathParts || [];
        model['@DataMember'] = dataMember?.join('.') || model['@DataMember'];
        model['@SourceName'] = sourceName || model['@SourceName'];
        serializer.deserialize(this, extend(model, { '@ItemType': 'Source' }));
    }
    getInfo() {
        return sourceSerializationInfo;
    }
    getDataSourceName() {
        return this.hasDataMember() ? this.sourceName().slice(0, this.sourceName().lastIndexOf(this.dataMember()) - 1)
            : this.sourceName();
    }
    getPath() {
        return [this.getDataSourceName()].concat(this.hasDataMember() ? [this.dataMember()] : []);
    }
    hasDataMember() {
        return this.dataMember() && this.sourceName().lastIndexOf(this.dataMember()) !== 0;
    }
}
