﻿/**
* DevExpress Analytics (query-builder\dataSource\json\jsonDataSource.js)
* Version:  24.2.7
* Build date: Apr 29, 2025
* Copyright (c) 2012 - 2025 Developer Express Inc. ALL RIGHTS RESERVED
* License: https://www.devexpress.com/Support/EULAs/universal.xml
*/
import { Disposable } from '../../../serializer/disposable';
import { ModelSerializer } from '../../../serializer/serializer';
import { RequestWrapper } from '../../utils/requestwrapper';
import { JsonSchemaProvider } from './jsonSchemaProvider';
import { JsonSchemaRootNode } from './jsonSchemaNode';
import { JsonSource } from './jsonSource';
import { DxDeferred } from '../../../core/utils/_jqueryUtils';
export class JsonDataSource extends Disposable {
    getInfo() {
        return jsonDataSourceSerializationInfo;
    }
    clone(_serializer) {
        const serializer = _serializer || new ModelSerializer();
        const serialized = serializer.serialize(this);
        return new JsonDataSource(serialized);
    }
    static from(model, serializer) {
        return new JsonDataSource(model, serializer);
    }
    static toJson(value, serializer, refs) {
        return serializer.serialize(value, jsonDataSourceSerializationInfo, refs);
    }
    constructor(model, serializer, requestWrapper = new RequestWrapper()) {
        super();
        serializer = serializer || new ModelSerializer();
        serializer.deserialize(this, model);
        this.jsonSchemaProvider = new JsonSchemaProvider(this, requestWrapper);
        this.source && this._disposables.push(this.source);
        this._disposables.push(this.connectionName.subscribe(() => {
            this.source.resetSource();
        }));
    }
    getSchema(parameters = []) {
        const deferred = new DxDeferred();
        this.jsonSchemaProvider.getJsonSchema(parameters)
            .done((schema) => {
            this.schema = schema;
            deferred.resolve(schema);
        })
            .fail(() => {
            this.schema = null;
            deferred.reject();
        });
        return deferred.promise();
    }
}
const jsonDataSourceSerializationInfo = [
    { propertyName: 'name', modelName: '@Name' },
    { propertyName: 'connectionName', modelName: '@ConnectionName' },
    { propertyName: 'rootElement', modelName: '@RootElement', defaultVal: 'root' },
    { propertyName: 'schema', modelName: 'Schema', from: JsonSchemaRootNode.from, toJsonObject: JsonSchemaRootNode.toJson },
    { propertyName: 'source', modelName: 'Source', from: JsonSource.from, toJsonObject: JsonSource.toJson }
];
